//+------------------------------------------------------------------+
//|                                               MAGICTaum 1min.mq4 |
//|                                     Maxss280 FXFisherman.com |
//|                                                                  |
//+------------------------------------------------------------------+
#define MAGICTaum  8888888
#property copyright "Maxss 280 FXFisherman.com"
#property link      ""

extern double Lots               = 0.1;
extern double MaximumRisk        = 0.02;
extern double DecreaseFactor     = 0;
//extern int    MaxOrders          = 5; //Not Used
//extern double TakeProfit         = 0.05;
extern double MAFast             = 4;
extern double MAFastShift        = 0;
extern double MASlow             = 12;
extern double MASlowShift        = 0;
extern double MALong             = 50;
extern double MALongShift        = 0;

//---Global Variables
string lastTrade = "None";
//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICTaum)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double maFAST,maSLOW,maLONG,stochFast,stochSlow;
   int    res;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Indicators 
   maFAST=iMA(NULL,PERIOD_H4,MAFast,0,MODE_EMA,PRICE_CLOSE,1);
   maSLOW=iMA(NULL,PERIOD_H4,MASlow,0,MODE_EMA,PRICE_CLOSE,1);
   maLONG=iMA(NULL,PERIOD_H4,MALong,0,MODE_EMA,PRICE_CLOSE,1);
   stochFast =iStochastic(NULL,PERIOD_D1,8,3,3,MODE_SMA,0,MODE_SIGNAL,1);
   stochSlow =iStochastic(NULL,PERIOD_D1,8,3,3,MODE_SMA,0,MODE_MAIN,1);
   
   
//---- sell conditions
   if(maFAST < maSLOW && maSLOW < maLONG && stochFast < stochSlow && lastTrade != "Sell")  
     {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,0,0,"",MAGICTaum,0,Red);
      //lastTrade = "Sell";
      return;
     }
//---- buy conditions
   if(maFAST > maSLOW && maSLOW > maLONG && stochFast > stochSlow && lastTrade != "Buy")  
     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,0,0,"",MAGICTaum,0,Blue);
      //lastTrade = "Buy";
      return;
     }
//----
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
   double maFAST,maSLOW;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   maFAST=iMA(NULL,PERIOD_H4,MAFast,0,MODE_EMA,PRICE_CLOSE,1);
   maSLOW=iMA(NULL,PERIOD_H4,MASlow,0,MODE_EMA,PRICE_CLOSE,1);
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICTaum || OrderSymbol()!=Symbol()) continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
         if(maFAST<maSLOW) OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(maFAST>maSLOW) OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   //If no orders Open
   if(CalculateCurrentOrders(Symbol())== 0)
   {
   CheckForOpen();
   }
   else
   {
   CheckForClose();
   }
//----
  }
//+------------------------------------------------------------------+